==> blancoHtmlParser-0.0.3-src.zip: src/blanco/html/parser/helper/BlancoHtmlNullContentHandler.java <==
/*******************************************************************************
 * Copyright (c) 2008 IGA Tosiki, NTT DATA BUSINESS BRAINS Corp.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    IGA Tosiki (NTT DATA BUSINESS BRAINS Corp.) - initial API and implementation
 *******************************************************************************/
/*
 * blanco Framework
 * Copyright (C) 2008 NTT DATA BUSINESS BRAINS CORPORATION
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 */
package blanco.html.parser.helper;

import java.io.IOException;
import java.util.List;

import blanco.html.parser.BlancoHtmlContentHandler;
import blanco.html.parser.valueobject.BlancoHtmlAttribute;

/**
 * ̃NX́AŏIIɂ͉ȂNXɂȂ܂B
 * 
 * @author IGA Tosiki
 */
public class BlancoHtmlNullContentHandler implements BlancoHtmlContentHandler {
    public void startDocument() throws IOException {
        System.out.println("startDocument()");
    }

    public void endDocument() throws IOException {
        System.out.println("endDocument()");
    }

    public void startElement(final String name,
            final List<BlancoHtmlAttribute> attrs) {
        System.out.println("startElement(" + name + ", " + attrs.toString()
                + ")");
    }

    public void endElement(final String name) {
        System.out.println("endElement(" + name + ")");
    }

    public void characters(final String argCharacters) {
        // System.out.println("characters(" + argCharacters + ")");
    }

    public void comments(final String argComments, final int argType) {
        // System.out.println("comments(" + argComments + ")");
    }

}

==> blancoHtmlParser-0.1.0-src.zip: src/blanco/html/parser/helper/BlancoHtmlNullContentHandler.java <==
/*******************************************************************************
 * Copyright (c) 2008 IGA Tosiki, NTT DATA BUSINESS BRAINS Corp.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    IGA Tosiki (NTT DATA BUSINESS BRAINS Corp.) - initial API and implementation
 *******************************************************************************/
/*
 * blanco Framework
 * Copyright (C) 2008 NTT DATA BUSINESS BRAINS CORPORATION
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 */
package blanco.html.parser.helper;

import java.io.IOException;
import java.util.List;

import blanco.html.parser.BlancoHtmlContentHandler;
import blanco.html.parser.valueobject.BlancoHtmlAttribute;

/**
 * Ȃ HTMLRecnh[B
 * 
 * @author IGA Tosiki
 */
public class BlancoHtmlNullContentHandler implements BlancoHtmlContentHandler {
    public void startDocument() throws IOException {
    }

    public void endDocument() throws IOException {
    }

    public void startElement(final String name,
            final List<BlancoHtmlAttribute> attrs) throws IOException {
    }

    public void endElement(final String name) throws IOException {
    }

    public void characters(final String argCharacters) throws IOException {
    }

    public void comments(final String argComments, final int argType)
            throws IOException {
    }
}
